Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(108)

Unified Diff: runtime/vm/parser.cc

Issue 133893007: Rename internal library dart:_collection-dev to dart:_internal. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Fix typo in dart2js Symbol lookup. Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/parser.cc
diff --git a/runtime/vm/parser.cc b/runtime/vm/parser.cc
index b53e2dc7ec56c128858d7a4b198259cfb635c0c0..434d32c78b304d1406adda0641754bd74953af5e 100644
--- a/runtime/vm/parser.cc
+++ b/runtime/vm/parser.cc
@@ -9806,9 +9806,9 @@ AstNode* Parser::ParseSymbolLiteral() {
} else {
ErrorMsg("illegal symbol literal");
}
// Lookup class Symbol from collection_dev library and call the
// constructor to create a symbol instance.
- const Library& lib = Library::Handle(Library::CollectionDevLibrary());
+ const Library& lib = Library::Handle(Library::InternalLibrary());
const Class& symbol_class = Class::Handle(lib.LookupClass(Symbols::Symbol()));
ASSERT(!symbol_class.IsNull());
ArgumentListNode* constr_args = new ArgumentListNode(symbol_pos);
@@ -9806,9 +9806,9 @@ AstNode* Parser::ParseSymbolLiteral() {
ErrorMsg("illegal symbol literal");
}
- // Lookup class Symbol from collection_dev library and call the
+ // Lookup class Symbol from internal library and call the
// constructor to create a symbol instance.

Powered by Google App Engine
This is Rietveld 408576698